@@ -4,11 +4,12 @@ use warnings;
 
 package Dist::Iller::Elk;
 
-our $VERSION = '0.1302'; # VERSION
+our $VERSION = '0.1400'; # VERSION
 
 use Moose();
 use MooseX::AttributeShortcuts();
 use MooseX::AttributeDocumented();
+use namespace::autoclean();
 use Moose::Exporter;
 
 Moose::Exporter->setup_import_methods(also => ['Moose']);
@@ -21,6 +22,7 @@ sub init_meta {
     Moose->init_meta(@_);
     MooseX::AttributeShortcuts->init_meta(for_class => $for_class);
     MooseX::AttributeDocumented->init_meta(for_class => $for_class);
+    namespace::autoclean->import(-cleanee => $for_class);
 }
 
 1;
@@ -37,7 +39,7 @@ Dist::Iller::Elk
 
 =head1 VERSION
 
-Version 0.1302, released 2016-02-03.
+Version 0.1400, released 2016-02-05.
 
 =head1 SOURCE
 
